@@ -1,17 +1,15 @@
 import time
 
-__version__ = "0.7.1"
+__version__ = "0.11.1"
 __author__ = "Lightning AI et al."
 __author_email__ = "pytorch@lightning.ai"
 __license__ = "Apache-2.0"
 __copyright__ = f"Copyright (c) 2022-{time.strftime('%Y')}, {__author__}."
 __homepage__ = "https://github.com/Lightning-AI/utilities"
-__docs__ = "PyTorch Lightning Sample project."
+__docs__ = "Lightning toolbox for across the our ecosystem."
 __long_doc__ = """
-What is it?
------------
-This package allows for sharing GH workflows, CI/CD assistance actions, and Python utilities across the Lightning
-ecosystem.
+This package allows for sharing GitHub workflows, CI/CD assistance actions, and Python utilities across the Lightning
+ecosystem - projects.
 """
 
 __all__ = [
